# Security Policy

## Supported Versions

These versions of the project are currently
being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 1.1.0   | :white_check_mark: |

## Reporting a Vulnerability

**Privately** disclose the issue to me, since i am the only maintainer as of now. You can contact me via [email](https://onceyt.github.io/)
or via other sources listed on my [site](https://onceyt.github.io/). Please allow reasonable time to address the issue before disclosing it publicly.
